@@ -3,6 +3,7 @@
 
 #include <QWidget>
 #include "appdownloader-comm/MaemoApplicationHandler.h"
+#include "loadwidget.h"
 
 namespace Ui {
     class LoginPrompt;
@@ -30,6 +31,7 @@ private:
     Ui::LoginPrompt *ui;
     MaemoApplicationHandler *applicationHandler;
     QString username;
+    LoadWidget *loading;
 };
 
 #endif // LOGINPROMPT_H
