@@ -31,11 +31,8 @@ public slots:
 
 
 private slots:
-    void openApplicationsList(QListWidgetItem *);
-    void openTopTenRate ();
-    void openTopTenDown ();
-    void openTopTenFresh ();
-    void openCategoryView();
+    void openListView (int);
+    void showPromoDetails ();
     void receivedPromoted (QList<MaemoApplication*>*);
     void promoPreviewReceived(QPixmap*,QString,QString);
     void receivedPromotedAppDetails(MaemoApplicationDetails*);
@@ -43,14 +40,18 @@ private slots:
 //    virtual void changeEvent(QEvent *e);
 
 private:
+    enum buttons {FRESHEST,CATEGORY,DOWNLOAD,RATING};
     Ui::MainWindow *m_ui;
     QList <SubWindow*> *topWidgets;
     QList <SubWindow*> *buffer;
     CategoryListWidget *categoryList;
     MaemoApplicationHandler *handler;
+    MaemoApplicationDetails *promoApp;
+    QPushButton *promotedButton;
     QString DEFAULTBC1;
     QString DEFAULTBC2;
     LoadWidget *loading;
+    QButtonGroup *buttonGroup;
 
 
 
